Crate gnss_protos

Crate gnss_protos 

GNSS-Protos

Rust Rust crates.io crates.io

License

GNSS-Protos

Ths library offers small and efficient decoders for GNSS protocols.

This library currently supports the following protos:

  • GPS: available on gps crate feature.

GPS proto

Available on gps crate feature.

We support the following GPS frames:

  • Ephemeris #1
  • Ephemeris #2
  • Ephemeris #3

License

This library is part of the RTK-rs framework which is delivered under the Mozilla V2 Public license.

Structs

GpsQzssDecodergps
GpsQzssFramegps
GPS / QZSS interpreted frame.
GpsQzssFrame1gps
GPS / QZSS Frame #1 interpretation
GpsQzssFrame2gps
GPS / QZSS Frame #2 interpretation
GpsQzssFrame3gps
GPS / QZSS Frame #3 interpretation
GpsQzssHowgps
GpsQzssHow marks the beginning of each frame, following GpsQzssTelemetry [GpsHowWord]
GpsQzssTelemetrygps
GpsQzssTelemetry marks the beginning of each frame

Enums

Error
GNSS-Proto error
GpsDataBytegps
GpsDataByte aligned to 32 bits
GpsErrorgps
GpsQzssFrameIdgps
GpsQzssSubframegps
GPS / QZSS Interpreted subframes

Constants

GPS_MIN_SIZEgps
Minimal allocation to encode a correct GPS data frame.
GPS_WORD_SIZEgps
GPS uses 30 bit data words, and is not aligned.