pub enum GpsDataByte {
MsbPadded(u8),
LsbPadded(u8),
Byte(u8),
}Available on crate feature
gps only.Expand description
GpsDataByte aligned to 32 bits
Variants
MsbPadded(u8)
2-bit MSB padding. Usually used at the beginning or stream termination by computers.
LsbPadded(u8)
2-bit LSB padding. Usually used at the beginning or stream termination by computers.
Byte(u8)
Plain byte
Implementations
Sourceimpl GpsDataByte
impl GpsDataByte
Sourcepub fn msb_padded(byte: u8) -> Self
pub fn msb_padded(byte: u8) -> Self
Stores provided byte as 2-bit MSB padded u8
Sourcepub fn lsb_padded(byte: u8) -> Self
pub fn lsb_padded(byte: u8) -> Self
Stores provided byte as 2-bit LSB padded u8