pub struct GpsQzssHow {
pub tow: u32,
pub alert: bool,
pub anti_spoofing: bool,
pub frame_id: GpsQzssFrameId,
}Available on crate feature
gps only.Expand description
GpsQzssHow marks the beginning of each frame, following GpsQzssTelemetry [GpsHowWord]
Fields
tow: u32TOW (in seconds)
alert: boolWhen alert is asserted, the SV URA may be worse than indicated in subframe 1 and user shall use this SV at their own risk.
anti_spoofing: boolA-S mode is ON in that SV
frame_id: GpsQzssFrameIdFollowing Frame ID (to decode following data words)
Implementations
Sourceimpl GpsQzssHow
impl GpsQzssHow