pub struct GpsQzssTelemetry {
pub message: u16,
pub integrity: bool,
pub reserved_bits: bool,
}Available on crate feature
gps only.Expand description
GpsQzssTelemetry marks the beginning of each frame
Fields
message: u1614-bit TLM Message
integrity: boolIntegrity bit is asserted means the conveying signal is provided with an enhanced level of integrity assurance.
reserved_bits: boolReserved bits
Implementations