GNSS-Protos
GNSS-Protos
Ths library offers small and efficient decoders for GNSS protocols.
This library currently supports the following protos:
GPS: available ongpscrate feature.
GPS proto
Available on gps crate feature.
We support the following GPS frames:
- Ephemeris #1
- Ephemeris #2
- Ephemeris #3
License
This library is part of the RTK-rs framework which is delivered under the Mozilla V2 Public license.
Structs
- GpsQzss
Decoder gps - GpsQzss
Frame gps - GPS / QZSS interpreted frame.
- GpsQzss
Frame1 gps - GPS / QZSS Frame #1 interpretation
- GpsQzss
Frame2 gps - GPS / QZSS Frame #2 interpretation
- GpsQzss
Frame3 gps - GPS / QZSS Frame #3 interpretation
- GpsQzss
How gps - GpsQzssHow marks the beginning of each frame, following GpsQzssTelemetry [GpsHowWord]
- GpsQzss
Telemetry gps - GpsQzssTelemetry marks the beginning of each frame
Enums
- Error
- GNSS-Proto error
- GpsData
Byte gps - GpsDataByte aligned to 32 bits
- GpsError
gps - GpsQzss
Frame Id gps - GpsQzss
Subframe gps - GPS / QZSS Interpreted subframes
Constants
- GPS_
MIN_ SIZE gps - Minimal allocation to encode a correct GPS data frame.
- GPS_
WORD_ SIZE gps - GPS uses 30 bit data words, and is not aligned.